<p align="center">
  <img src="https://github.com/nitrictech/python-sdk/raw/main/docs/assets/dot-matrix-logo-python.png" alt="Nitric Python SDK Logo"/>
</p>

![test status](https://github.com/nitrictech/python-sdk/actions/workflows/test.yaml/badge.svg?branch=main)
[![codecov](https://codecov.io/gh/nitrictech/python-sdk/branch/main/graph/badge.svg?token=SBFRNSZ4ZF)](https://codecov.io/gh/nitrictech/python-sdk)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=nitrictech_python-sdk&metric=alert_status)](https://sonarcloud.io/dashboard?id=nitrictech_python-sdk)

# Nitric Python SDK

The Python SDK supports the use of the cloud-portable [Nitric](https://nitric.io) framework with Python 3.

> The Nitric Python SDK is currently in Preview, API changes are likely prior to v1.x release.

Read full documentation [here](https://nitrictech.github.io/python-sdk/).

## Prerequisites

- Python 3.8+

## Getting Started

### Using the [Nitric CLI](https://github.com/nitric-tech/cli)

> nitric is included in all python related projects by default

```bash
nitric make:stack
```

Then select `official/Python Stack`

### Adding to an existing project

**pip**

```bash
# Install the Nitric SDK
pip3 install nitric
```

## Usage
[Nitric Documentation](https://nitric.io/docs)